carbon2-commit: Handle printing correctly on non-mswindows.
16 years, 7 months
Aidan Kehoe
changeset: 4485:554b9d31e7a5353a725b4f326241a895a237c815
user: Aidan Kehoe <kehoea(a)parhasard.net>
date: Tue May 13 14:56:38 2008 +0200
files: lisp/ChangeLog lisp/printer.el
description:
Handle printing correctly on non-mswindows.
2008-05-13 Aidan Kehoe <kehoea(a)parhasard.net>
* printer.el (generic-print-region):
(generic-print-buffer):
Use #'valid-device-type-p instead of #'valid-specifier-tag-p to
check if the msprinter device is available, now that msprinter is
always available as a specifier tag.
diff -r d9b9b5f903863b3ac33713441ea9c91e2553f144 -r 554b9d31e7a5353a725b4f326241a895a237c815 lisp/ChangeLog
--- a/lisp/ChangeLog Tue May 13 20:16:53 2008 +0200
+++ b/lisp/ChangeLog Tue May 13 14:56:38 2008 +0200
@@ -1,3 +1,11 @@ 2008-05-11 Aidan Kehoe <kehoea@parhasa
+2008-05-13 Aidan Kehoe <kehoea(a)parhasard.net>
+
+ * printer.el (generic-print-region):
+ (generic-print-buffer):
+ Use #'valid-device-type-p instead of #'valid-specifier-tag-p to
+ check if the msprinter device is available, now that msprinter is
+ always available as a specifier tag.
+
2008-05-11 Aidan Kehoe <kehoea(a)parhasard.net>
* disp-table.el (make-display-table):
diff -r d9b9b5f903863b3ac33713441ea9c91e2553f144 -r 554b9d31e7a5353a725b4f326241a895a237c815 lisp/printer.el
--- a/lisp/printer.el Tue May 13 20:16:53 2008 +0200
+++ b/lisp/printer.el Tue May 13 14:56:38 2008 +0200
@@ -263,7 +263,7 @@ If BUFFER is nil or omitted, the current
(let* ((print-region (and (interactive-p) (region-active-p)))
(start (if print-region (region-beginning) (point-min buffer)))
(end (if print-region (region-end) (point-max buffer))))
- (if (or (not (valid-specifier-tag-p 'msprinter))
+ (if (or (not (valid-device-type-p 'msprinter))
(not display-print-dialog))
(generic-print-region start end buffer)
(let* ((d (Printer-get-device))
@@ -312,7 +312,7 @@ Recognized properties are the same as th
to-page Last page to print, inclusive, If omitted, printing ends at
the end.
copies Number of copies to print. If omitted, one copy is printed."
- (cond ((valid-specifier-tag-p 'msprinter)
+ (cond ((valid-device-type-p 'msprinter)
;; loop, printing one copy of document per loop. kill and
;; re-create the frame each time so that we eject the piece
;; of paper at the end even if we're printing more than one
_______________________________________________
XEmacs-Patches mailing list
XEmacs-Patches(a)xemacs.org
http://calypso.tux.org/cgi-bin/mailman/listinfo/xemacs-patches
carbon2-commit: Correct coding-category determination for 8-bit-fixed coding systems.
16 years, 7 months
Aidan Kehoe
changeset: 4486:04ec3340612e4e1b351e381fdfd75d0813fb1dec
user: Aidan Kehoe <kehoea(a)parhasard.net>
date: Wed May 14 23:43:12 2008 +0200
files: lisp/ChangeLog lisp/mule/mule-coding.el
description:
Correct coding-category determination for 8-bit-fixed coding systems.
2008-05-14 Aidan Kehoe <kehoea(a)parhasard.net>
* mule/mule-coding.el (make-8-bit-choose-category):=20
Control-1 characters extend from #x80 to #x9F (inclusive),
not from #x80 to #xBF.
diff -r 554b9d31e7a5353a725b4f326241a895a237c815 -r 04ec3340612e4e1b351e381fdfd75d0813fb1dec lisp/ChangeLog
--- a/lisp/ChangeLog Tue May 13 14:56:38 2008 +0200
+++ b/lisp/ChangeLog Wed May 14 23:43:12 2008 +0200
@@ -1,3 +1,9 @@ 2008-05-13 Aidan Kehoe <kehoea@parhasa
+2008-05-14 Aidan Kehoe <kehoea(a)parhasard.net>
+
+ * mule/mule-coding.el (make-8-bit-choose-category):=20
+ Control-1 characters extend from #x80 to #x9F (inclusive),
+ not from #x80 to #xBF.
+
2008-05-13 Aidan Kehoe <kehoea(a)parhasard.net>
* printer.el (generic-print-region):
diff -r 554b9d31e7a5353a725b4f326241a895a237c815 -r 04ec3340612e4e1b351e381fdfd75d0813fb1dec lisp/mule/mule-coding.el
--- a/lisp/mule/mule-coding.el Tue May 13 14:56:38 2008 +0200
+++ b/lisp/mule/mule-coding.el Wed May 14 23:43:12 2008 +0200
@@ -533,7 +533,7 @@ disk to XEmacs characters for some fixed
(check-argument-range (length decode-table) #x100 #x100)
(block category
(loop
- for i from #x80 to #xBF
+ for i from #x80 to #x9F
do (unless (= i (aref decode-table i))
(return-from category 'no-conversion)))
'iso-8-1))
_______________________________________________
XEmacs-Patches mailing list
XEmacs-Patches(a)xemacs.org
http://calypso.tux.org/cgi-bin/mailman/listinfo/xemacs-patches
carbon2-commit: Provide SHEBANG_PROGNAME on Win32; correct a bug with it and string concat'ing
16 years, 7 months
Aidan Kehoe
changeset: 4484:d9b9b5f903863b3ac33713441ea9c91e2553f144
user: Aidan Kehoe <kehoea(a)parhasard.net>
date: Tue May 13 20:16:53 2008 +0200
files: nt/ChangeLog nt/xemacs.mak src/ChangeLog src/emacs.c
description:
Provide SHEBANG_PROGNAME on Win32; correct a bug with it and string concat'ing
nt/ChangeLog addition:
2008-05-13 Aidan Kehoe <kehoea(a)parhasard.net>
* xemacs.mak (PROGRAM_DEFINES):
Provide SHEBANG_PROGNAME on Win32 too.
src/ChangeLog addition:
2008-05-13 Aidan Kehoe <kehoea(a)parhasard.net>
* emacs.c (SHEBANG_EXE_PROGNAME_LENGTH):
Use WEXTSTRING separately on the two concatenated strings,
avoiding an error on Win32.
diff -r 2fddd822ce87c676cc23043237fdfa35cfd886ac -r d9b9b5f903863b3ac33713441ea9c91e2553f144 nt/ChangeLog
--- a/nt/ChangeLog Tue May 13 20:11:51 2008 +0200
+++ b/nt/ChangeLog Tue May 13 20:16:53 2008 +0200
@@ -1,3 +1,8 @@ 2008-01-25 Michael Sperber <mike@xemac
+2008-05-13 Aidan Kehoe <kehoea(a)parhasard.net>
+
+ * xemacs.mak (PROGRAM_DEFINES):
+ Provide SHEBANG_PROGNAME on Win32 too.
+
2008-01-25 Michael Sperber <mike(a)xemacs.org>
* xemacs.mak (version.sh): Generate version.sh via Mercurial.
diff -r 2fddd822ce87c676cc23043237fdfa35cfd886ac -r d9b9b5f903863b3ac33713441ea9c91e2553f144 nt/xemacs.mak
--- a/nt/xemacs.mak Tue May 13 20:11:51 2008 +0200
+++ b/nt/xemacs.mak Tue May 13 20:16:53 2008 +0200
@@ -427,6 +427,7 @@ PROGRAM_DEFINES=-DINFODOCK \
-DPATH_VERSION=\"$(INFODOCK_VERSION_STRING)\" \
-DPATH_PROGNAME=\"infodock\" \
-DEMACS_PROGNAME=\"infodock\" \
+ -DSHEBANG_PROGNAME=\"infodock-script\" \
-DEMACS_VERSION=\"$(INFODOCK_VERSION_STRING)\" \
-DINFODOCK_MAJOR_VERSION=$(infodock_major_version) \
-DINFODOCK_MINOR_VERSION=$(infodock_minor_version) \
@@ -444,7 +445,7 @@ PROGRAM_DEFINES= \
-DPATH_VERSION=\"$(XEMACS_VERSION_STRING)\" \
-DPATH_PROGNAME=\"xemacs\" \
-DEMACS_VERSION=\"$(XEMACS_VERSION_STRING)\" \
- -DEMACS_PROGNAME=\"xemacs\"
+ -DEMACS_PROGNAME=\"xemacs\" -DSHEBANG_PROGNAME=\"xemacs-script\"
!endif
########################### Set up installation and package directories.
diff -r 2fddd822ce87c676cc23043237fdfa35cfd886ac -r d9b9b5f903863b3ac33713441ea9c91e2553f144 src/ChangeLog
--- a/src/ChangeLog Tue May 13 20:11:51 2008 +0200
+++ b/src/ChangeLog Tue May 13 20:16:53 2008 +0200
@@ -1,3 +1,9 @@ 2008-05-13 Aidan Kehoe <kehoea@parhasa
+2008-05-13 Aidan Kehoe <kehoea(a)parhasard.net>
+
+ * emacs.c (SHEBANG_EXE_PROGNAME_LENGTH):
+ Use WEXTSTRING separately on the two concatenated strings,
+ avoiding an error on Win32.
+
2008-05-13 Aidan Kehoe <kehoea(a)parhasard.net>
* config.h.in (_CRT_NONSTDC_NO_DEPRECATE):
diff -r 2fddd822ce87c676cc23043237fdfa35cfd886ac -r d9b9b5f903863b3ac33713441ea9c91e2553f144 src/emacs.c
--- a/src/emacs.c Tue May 13 20:11:51 2008 +0200
+++ b/src/emacs.c Tue May 13 20:16:53 2008 +0200
@@ -958,7 +958,7 @@ main_1 (int argc, Wexttext **argv, Wextt
#define SHEBANG_PROGNAME_LENGTH \
(int)((sizeof (WEXTSTRING (SHEBANG_PROGNAME)) - sizeof (WEXTSTRING (""))))
#define SHEBANG_EXE_PROGNAME_LENGTH \
- (int)(sizeof (WEXTSTRING (SHEBANG_PROGNAME ".exe")) \
+ (int)(sizeof (WEXTSTRING (SHEBANG_PROGNAME) WEXTSTRING(".exe")) \
- sizeof (WEXTSTRING ("")))
{
_______________________________________________
XEmacs-Patches mailing list
XEmacs-Patches(a)xemacs.org
http://calypso.tux.org/cgi-bin/mailman/listinfo/xemacs-patches
carbon2-commit: #define _CRT_NONSTDC_NO_DEPRECATE on Win32
16 years, 7 months
Aidan Kehoe
changeset: 4483:2fddd822ce87c676cc23043237fdfa35cfd886ac
user: Aidan Kehoe <kehoea(a)parhasard.net>
date: Tue May 13 20:11:51 2008 +0200
files: src/ChangeLog src/config.h.in
description:
#define _CRT_NONSTDC_NO_DEPRECATE on Win32
2008-05-13 Aidan Kehoe <kehoea(a)parhasard.net>
* config.h.in (_CRT_NONSTDC_NO_DEPRECATE):
Define this, to avoid warnings about using standard POSIX and C9X
functions on Win32; fixes part of Matthew Persico's problems of
9ea6aaa80805081832r1a3308e9wb6d2bfea7457379f(a)mail.gmail.com .
diff -r c785f98c6737d0da7774c975790b6247717af226 -r 2fddd822ce87c676cc23043237fdfa35cfd886ac src/ChangeLog
--- a/src/ChangeLog Tue May 13 20:08:28 2008 +0200
+++ b/src/ChangeLog Tue May 13 20:11:51 2008 +0200
@@ -1,3 +1,10 @@ 2008-01-20 Aidan Kehoe <kehoea@parhasa
+2008-05-13 Aidan Kehoe <kehoea(a)parhasard.net>
+
+ * config.h.in (_CRT_NONSTDC_NO_DEPRECATE):
+ Define this, to avoid warnings about using standard POSIX and C9X
+ functions on Win32; fixes part of Matthew Persico's problems of
+ 9ea6aaa80805081832r1a3308e9wb6d2bfea7457379f(a)mail.gmail.com .
+
2008-01-20 Aidan Kehoe <kehoea(a)parhasard.net>
* config.h.in: Add SHEBANG_PROGNAME.
diff -r c785f98c6737d0da7774c975790b6247717af226 -r 2fddd822ce87c676cc23043237fdfa35cfd886ac src/config.h.in
--- a/src/config.h.in Tue May 13 20:08:28 2008 +0200
+++ b/src/config.h.in Tue May 13 20:11:51 2008 +0200
@@ -875,6 +875,7 @@ things are arranged in config.h.in. In
"deprecated" in favor of Microsoft-specific "secure" ones (!)
This must go *before* the inclusion of any system files. */
#define _CRT_SECURE_NO_DEPRECATE
+#define _CRT_NONSTDC_NO_DEPRECATE
#endif
/* alloca twiddling.
_______________________________________________
XEmacs-Patches mailing list
XEmacs-Patches(a)xemacs.org
http://calypso.tux.org/cgi-bin/mailman/listinfo/xemacs-patches
carbon2-commit: Fix path-configuration glitches:
16 years, 7 months
Aidan Kehoe
changeset: 4481:49f8ed0345005a02146572b11bdb55f0127d3bf2
user: Mike Sperber <sperber(a)deinprogramm.de>
date: Mon May 12 11:53:04 2008 +0200
files: ChangeLog configure configure.ac
description:
Fix path-configuration glitches:
2008-05-12 Michael Sperber <mike(a)xemacs.org>
* configure.ac:
A number of the checks that tried to determine whether an explicit
path was specified were wrong.
Also, add an AC_SUBST for INFOPATH.
diff -r 1f0aa40cafe090edac8b2a0584e86050da240da7 -r 49f8ed0345005a02146572b11bdb55f0127d3bf2 ChangeLog
--- a/ChangeLog Sun May 11 12:03:07 2008 +0200
+++ b/ChangeLog Mon May 12 11:53:04 2008 +0200
@@ -1,3 +1,10 @@ 2008-05-07 Aidan Kehoe <kehoea@parhasa
+2008-05-12 Michael Sperber <mike(a)xemacs.org>
+
+ * configure.ac:
+ A number of the checks that tried to determine whether an explicit
+ path was specified were wrong.
+ Also, add an AC_SUBST for INFOPATH.
+
2008-05-07 Aidan Kehoe <kehoea(a)parhasard.net>
* configure.ac (XE_EXPAND_VARIABLE): Call AC_SUBST on
diff -r 1f0aa40cafe090edac8b2a0584e86050da240da7 -r 49f8ed0345005a02146572b11bdb55f0127d3bf2 configure
--- a/configure Sun May 11 12:03:07 2008 +0200
+++ b/configure Mon May 12 11:53:04 2008 +0200
@@ -779,6 +779,7 @@ INFODIR
INFODIR
infopath
INFOPATH_USER_DEFINED
+INFOPATH
early_packages
EARLY_PACKAGE_DIRECTORIES_USER_DEFINED
EARLY_PACKAGE_DIRECTORIES
@@ -4548,39 +4549,6 @@ while true; do
*) break ;;
esac
done
-
-if test "x$datadir_expanded" != "x$prefix_expanded/share"
-then
- cat >>confdefs.h <<\_ACEOF
-#define INFODIR_USER_DEFINED 1
-_ACEOF
-
- cat >>confdefs.h <<\_ACEOF
-#define LISPDIR_USER_DEFINED 1
-_ACEOF
-
- cat >>confdefs.h <<\_ACEOF
-#define ETCDIR_USER_DEFINED 1
-_ACEOF
-
-fi
-
-if test "x$lib_expanded" != "x$prefix_expanded/lib"
-then
- cat >>confdefs.h <<\_ACEOF
-#define MODULEDIR_USER_DEFINED 1
-_ACEOF
-
- cat >>confdefs.h <<\_ACEOF
-#define ARCHLIBDIR_USER_DEFINED 1
-_ACEOF
-
- cat >>confdefs.h <<\_ACEOF
-#define DOCDIR_USER_DEFINED 1
-_ACEOF
-
-fi
-
exec_prefix_expanded=$exec_prefix
while true; do
case "$exec_prefix_expanded" in
@@ -4595,15 +4563,6 @@ while true; do
*) break ;;
esac
done
-
-if test "x$libdir_expanded" != "x$exec_prefix_expanded/lib"
-then
- cat >>confdefs.h <<\_ACEOF
-#define ARCHLIBDIR_USER_DEFINED 1
-_ACEOF
-
-fi
-
mandir_expanded=$mandir
while true; do
case "$mandir_expanded" in
@@ -4611,12 +4570,6 @@ while true; do
*) break ;;
esac
done
-
-if test "x$mandir_expanded" = "x$prefix_expanded/man"
-then
- mandir='${datarootdir}/man/man1'
-fi
-
infodir_expanded=$infodir
while true; do
case "$infodir_expanded" in
@@ -4625,7 +4578,39 @@ while true; do
esac
done
-if test "x$infodir_expanded" != "x${prefix_expanded}/info"
+if test "x$datadir_expanded" != "x$prefix_expanded/share"
+then
+ cat >>confdefs.h <<\_ACEOF
+#define INFODIR_USER_DEFINED 1
+_ACEOF
+
+ cat >>confdefs.h <<\_ACEOF
+#define LISPDIR_USER_DEFINED 1
+_ACEOF
+
+ cat >>confdefs.h <<\_ACEOF
+#define ETCDIR_USER_DEFINED 1
+_ACEOF
+
+fi
+
+if test "x$libdir_expanded" != "x$prefix_expanded/lib"
+then
+ cat >>confdefs.h <<\_ACEOF
+#define MODULEDIR_USER_DEFINED 1
+_ACEOF
+
+ cat >>confdefs.h <<\_ACEOF
+#define ARCHLIBDIR_USER_DEFINED 1
+_ACEOF
+
+ cat >>confdefs.h <<\_ACEOF
+#define DOCDIR_USER_DEFINED 1
+_ACEOF
+
+fi
+
+if test "x$infodir_expanded" != "x${prefix_expanded}/share/info"
then
cat >>confdefs.h <<\_ACEOF
#define INFODIR_USER_DEFINED 1
@@ -39133,6 +39118,7 @@ while true; do
*) break ;;
esac
done
+
test -n "$with_user_packages" && with_early_packages=$with_user_packages
early_packages=$with_early_packages
@@ -40576,6 +40562,7 @@ INFODIR!$INFODIR$ac_delim
INFODIR!$INFODIR$ac_delim
infopath!$infopath$ac_delim
INFOPATH_USER_DEFINED!$INFOPATH_USER_DEFINED$ac_delim
+INFOPATH!$INFOPATH$ac_delim
early_packages!$early_packages$ac_delim
EARLY_PACKAGE_DIRECTORIES_USER_DEFINED!$EARLY_PACKAGE_DIRECTORIES_USER_DEFINED$ac_delim
EARLY_PACKAGE_DIRECTORIES!$EARLY_PACKAGE_DIRECTORIES$ac_delim
@@ -40632,7 +40619,7 @@ LTLIBOBJS!$LTLIBOBJS$ac_delim
LTLIBOBJS!$LTLIBOBJS$ac_delim
_ACEOF
- if test `sed -n "s/.*$ac_delim\$/X/p" conf$$subs.sed | grep -c X` = 75; then
+ if test `sed -n "s/.*$ac_delim\$/X/p" conf$$subs.sed | grep -c X` = 76; then
break
elif $ac_last_try; then
{ { echo "$as_me:$LINENO: error: could not make $CONFIG_STATUS" >&5
diff -r 1f0aa40cafe090edac8b2a0584e86050da240da7 -r 49f8ed0345005a02146572b11bdb55f0127d3bf2 configure.ac
--- a/configure.ac Sun May 11 12:03:07 2008 +0200
+++ b/configure.ac Mon May 12 11:53:04 2008 +0200
@@ -1068,6 +1068,10 @@ done])dnl XE_EXPAND_VARIABLE
XE_EXPAND_VARIABLE(prefix,prefix_expanded)
XE_EXPAND_VARIABLE(datadir,datadir_expanded)
+XE_EXPAND_VARIABLE(exec_prefix,exec_prefix_expanded)
+XE_EXPAND_VARIABLE(libdir,libdir_expanded)
+XE_EXPAND_VARIABLE(mandir,mandir_expanded)
+XE_EXPAND_VARIABLE(infodir,infodir_expanded)
if test "x$datadir_expanded" != "x$prefix_expanded/share"
then
@@ -1076,31 +1080,14 @@ then
AC_DEFINE(ETCDIR_USER_DEFINED)
fi
-if test "x$lib_expanded" != "x$prefix_expanded/lib"
+if test "x$libdir_expanded" != "x$prefix_expanded/lib"
then
AC_DEFINE(MODULEDIR_USER_DEFINED)
AC_DEFINE(ARCHLIBDIR_USER_DEFINED)
AC_DEFINE(DOCDIR_USER_DEFINED)
fi
-XE_EXPAND_VARIABLE(exec_prefix,exec_prefix_expanded)
-XE_EXPAND_VARIABLE(libdir,libdir_expanded)
-
-if test "x$libdir_expanded" != "x$exec_prefix_expanded/lib"
-then
- AC_DEFINE(ARCHLIBDIR_USER_DEFINED)
-fi
-
-XE_EXPAND_VARIABLE(mandir,mandir_expanded)
-
-if test "x$mandir_expanded" = "x$prefix_expanded/man"
-then
- mandir='${datarootdir}/man/man1'
-fi
-
-XE_EXPAND_VARIABLE(infodir,infodir_expanded)
-
-if test "x$infodir_expanded" != "x${prefix_expanded}/info"
+if test "x$infodir_expanded" != "x${prefix_expanded}/share/info"
then
AC_DEFINE(INFODIR_USER_DEFINED)
else
@@ -5771,6 +5758,7 @@ AC_SUBST(infopath,$with_infopath)
AC_SUBST(infopath,$with_infopath)
AC_SUBST(INFOPATH_USER_DEFINED)
XE_EXPAND_VARIABLE(with_info_path,INFOPATH)
+AC_SUBST(INFOPATH)
test -n "$with_user_packages" && with_early_packages=$with_user_packages
AC_SUBST(early_packages,$with_early_packages)
_______________________________________________
XEmacs-Patches mailing list
XEmacs-Patches(a)xemacs.org
http://calypso.tux.org/cgi-bin/mailman/listinfo/xemacs-patches
carbon2-commit: Pass READ_BINARY to scan_lisp_file, scan_c_file in make-docfile.c
16 years, 7 months
Aidan Kehoe
changeset: 4482:c785f98c6737d0da7774c975790b6247717af226
user: Aidan Kehoe <kehoea(a)parhasard.net>
date: Tue May 13 20:08:28 2008 +0200
files: lib-src/ChangeLog lib-src/make-docfile.c
description:
Pass READ_BINARY to scan_lisp_file, scan_c_file in make-docfile.c
2008-05-13 Aidan Kehoe <kehoea(a)parhasard.net>
* make-docfile.c (scan_file):
Pass READ_BINARY to scan_lisp_file, scan_c_file; avoids an
assertion failure with Visual C++ 2005 Express Edition, and is
logically more coherent, given that our Lisp and C files are saved
with Unix line endings.
diff -r 49f8ed0345005a02146572b11bdb55f0127d3bf2 -r c785f98c6737d0da7774c975790b6247717af226 lib-src/ChangeLog
--- a/lib-src/ChangeLog Mon May 12 11:53:04 2008 +0200
+++ b/lib-src/ChangeLog Tue May 13 20:08:28 2008 +0200
@@ -1,3 +1,11 @@ 2007-08-27 Mike Sperber <mike(a)xemacs.o
+2008-05-13 Aidan Kehoe <kehoea(a)parhasard.net>
+
+ * make-docfile.c (scan_file):
+ Pass READ_BINARY to scan_lisp_file, scan_c_file; avoids an
+ assertion failure with Visual C++ 2005 Express Edition, and is
+ logically more coherent, given that our Lisp and C files are saved
+ with Unix line endings.
+
2007-08-27 Mike Sperber <mike(a)xemacs.org>
* config.values.in (datarootdir): Add.
diff -r 49f8ed0345005a02146572b11bdb55f0127d3bf2 -r c785f98c6737d0da7774c975790b6247717af226 lib-src/make-docfile.c
--- a/lib-src/make-docfile.c Mon May 12 11:53:04 2008 +0200
+++ b/lib-src/make-docfile.c Tue May 13 20:08:28 2008 +0200
@@ -306,12 +306,12 @@ scan_file (const char *filename)
else if (ellcc == 0 && len > 3 && !strcmp (filename + len - 3, ".el"))
{
Current_file_type = el_file;
- return scan_lisp_file (filename, READ_TEXT);
+ return scan_lisp_file (filename, READ_BINARY);
}
else
{
Current_file_type = c_file;
- return scan_c_file (filename, READ_TEXT);
+ return scan_c_file (filename, READ_BINARY);
}
}
_______________________________________________
XEmacs-Patches mailing list
XEmacs-Patches(a)xemacs.org
http://calypso.tux.org/cgi-bin/mailman/listinfo/xemacs-patches
carbon2-commit: Small improvements in disp-table.el, mule/cyril-util.el.
16 years, 7 months
Aidan Kehoe
changeset: 4480:1f0aa40cafe090edac8b2a0584e86050da240da7
user: Aidan Kehoe <kehoea(a)parhasard.net>
date: Sun May 11 12:03:07 2008 +0200
files: lisp/ChangeLog lisp/disp-table.el lisp/mule/cyril-util.el
description:
Small improvements in disp-table.el, mule/cyril-util.el.
2008-05-11 Aidan Kehoe <kehoea(a)parhasard.net>
* disp-table.el (make-display-table):
[...] Also, I previously said #xFF when I meant
?\xFF; correct this.
* mule/cyril-util.el (standard-display-cyrillic-translit):
Make the selection of the default language more sensible; change
the API a little to make a sensible default Cyrillic language
available, checking current-language-environment.
diff -r 29efd169efe7d04bdb511dcd275f5691dc149997 -r 1f0aa40cafe090edac8b2a0584e86050da240da7 lisp/ChangeLog
--- a/lisp/ChangeLog Sun May 11 11:24:01 2008 +0200
+++ b/lisp/ChangeLog Sun May 11 12:03:07 2008 +0200
@@ -2,7 +2,12 @@ 2008-05-11 Aidan Kehoe <kehoea@parhasa
* disp-table.el (make-display-table):
Update the example code to make it more general, and more
- compatible with GNU.
+ compatible with GNU. Also, I previously said #xFF when I meant
+ ?\xFF; correct this.
+ * mule/cyril-util.el (standard-display-cyrillic-translit):
+ Make the selection of the default language more sensible; change
+ the API a little to make a sensible default Cyrillic language
+ available, checking current-language-environment.
2007-07-21 Aidan Kehoe <kehoea(a)parhasard.net>
diff -r 29efd169efe7d04bdb511dcd275f5691dc149997 -r 1f0aa40cafe090edac8b2a0584e86050da240da7 lisp/disp-table.el
--- a/lisp/disp-table.el Sun May 11 11:24:01 2008 +0200
+++ b/lisp/disp-table.el Sun May 11 12:03:07 2008 +0200
@@ -39,7 +39,7 @@
This returns a generic character table; previously it returned a vector, but
that was not helpful when dealing with internationalized characters above
-#xFF. See `make-char-table' for details of character tables in general. To
+?\xFF. See `make-char-table' for details of character tables in general. To
write code that works with both vectors and character tables, add something
like the following to the beginning of your file, and use
`put-display-table' to set what a given character is displayed as, and
diff -r 29efd169efe7d04bdb511dcd275f5691dc149997 -r 1f0aa40cafe090edac8b2a0584e86050da240da7 lisp/mule/cyril-util.el
--- a/lisp/mule/cyril-util.el Sun May 11 11:24:01 2008 +0200
+++ b/lisp/mule/cyril-util.el Sun May 11 12:03:07 2008 +0200
@@ -43,7 +43,8 @@
"*List of known Cyrillic languages")
;;;###autoload
-(defun standard-display-cyrillic-translit (&optional cyrillic-language)
+(defun standard-display-cyrillic-translit (&optional cyrillic-language
+ disable)
"Display a cyrillic buffer using a transliteration.
For readability, the table is slightly
different from the one used for the input method `cyrillic-translit'.
@@ -51,19 +52,26 @@ The argument is a string which specifies
The argument is a string which specifies which language you are using;
that affects the choice of transliterations slightly.
Possible values are listed in 'cyrillic-language-alist'.
-If the argument is t, we use the default cyrillic transliteration.
-If the argument is nil, we return the display table to its standard state."
+
+Specifying a prefix arg, by preceding
+\\[standard-display-cyrillic-translit] with \\[universal-argument]
+turns off Cyrillic display. Noninteractively, the DISABLE argument
+does the same thing. "
(interactive
(list
- (let* ((completion-ignore-case t))
- (completing-read
- "Cyrillic language (default nil): "
- cyrillic-language-alist nil t nil nil nil))))
- (when (equal cyrillic-language "")
- (setq cyrillic-language nil))
+ (let* ((completion-ignore-case t)
+ (default-language (if (assoc-ignore-case
+ current-language-environment
+ cyrillic-language-alist)
+ current-language-environment
+ "Russian")))
+ (or current-prefix-arg
+ (completing-read
+ (format "Cyrillic language (default %s): " default-language)
+ cyrillic-language-alist nil t nil nil default-language)))))
(frob-display-table
(lambda (display-table)
- (if (null cyrillic-language)
+ (if (or disable current-prefix-arg)
(if (char-table-p display-table)
(remove-char-table 'cyrillic-iso8859-5 display-table))
(put-display-table ?,LP(B "a" display-table)
_______________________________________________
XEmacs-Patches mailing list
XEmacs-Patches(a)xemacs.org
http://calypso.tux.org/cgi-bin/mailman/listinfo/xemacs-patches
carbon2-commit: Improve portable sample implementations for #'{put, get}-display-table
16 years, 7 months
Aidan Kehoe
changeset: 4478:82f8351e71c88a406868ece693e521789c8a7441
user: Aidan Kehoe <kehoea(a)parhasard.net>
date: Sun May 11 11:20:24 2008 +0200
files: lisp/ChangeLog lisp/disp-table.el
description:
Improve portable sample implementations for #'{put,get}-display-table
2008-05-11 Aidan Kehoe <kehoea(a)parhasard.net>
* disp-table.el (make-display-table):
Update the example code to make it more general, and more
compatible with GNU.
diff -r e214ff9f9507794f61ad09d81e5f9272447c87d2 -r 82f8351e71c88a406868ece693e521789c8a7441 lisp/ChangeLog
--- a/lisp/ChangeLog Mon Dec 24 20:22:08 2007 +0100
+++ b/lisp/ChangeLog Sun May 11 11:20:24 2008 +0200
@@ -1,3 +1,9 @@ 2007-07-21 Aidan Kehoe <kehoea@parhasa
+2008-05-11 Aidan Kehoe <kehoea(a)parhasard.net>
+
+ * disp-table.el (make-display-table):
+ Update the example code to make it more general, and more
+ compatible with GNU.
+
2007-07-21 Aidan Kehoe <kehoea(a)parhasard.net>
* mule/cyril-util.el:
diff -r e214ff9f9507794f61ad09d81e5f9272447c87d2 -r 82f8351e71c88a406868ece693e521789c8a7441 lisp/disp-table.el
--- a/lisp/disp-table.el Mon Dec 24 20:22:08 2007 +0100
+++ b/lisp/disp-table.el Sun May 11 11:20:24 2008 +0200
@@ -48,23 +48,19 @@ as:
\(defun-when-void put-display-table (range value display-table)
\"Set the value for char RANGE to VALUE in DISPLAY-TABLE. \"
- (ecase (type-of display-table)
- (vector
- (aset display-table range value))
- (char-table
- (put-char-table range value display-table))))
+ (if (sequencep display-table)
+ (aset display-table range value)
+ (put-char-table range value display-table)))
\(defun-when-void get-display-table (character display-table)
\"Find value for CHARACTER in DISPLAY-TABLE. \"
- (ecase (type-of display-table)
- (vector
- (aref display-table character))
- (char-table
- (get-char-table character display-table))))
+ (if (sequencep display-table)
+ (aref display-table character)
+ (get-char-table character display-table)))
In this implementation, `put-display-table' and `get-display-table' are
aliases of `put-char-table' and `get-char-table' respectively, and are
-always available. "
+always available."
(make-char-table 'generic))
;;;###autoload
_______________________________________________
XEmacs-Patches mailing list
XEmacs-Patches(a)xemacs.org
http://calypso.tux.org/cgi-bin/mailman/listinfo/xemacs-patches
carbon2-commit: Use char-tables, not vectors, to instantiate the display table specifiers.
16 years, 7 months
Aidan Kehoe
changeset: 4477:e214ff9f9507794f61ad09d81e5f9272447c87d2
parent: 4366:cc293ef846d240af187a523bb32eb5e26a083531
user: Aidan Kehoe <kehoea(a)parhasard.net>
date: Mon Dec 24 20:22:08 2007 +0100
files: lisp/ChangeLog lisp/disp-table.el lisp/font.el lisp/mule/cyril-util.el lisp/x-init.el
description:
Use char-tables, not vectors, to instantiate the display table specifiers.
2007-07-21 Aidan Kehoe <kehoea(a)parhasard.net>
* mule/cyril-util.el:
* mule/cyril-util.el (cyrillic-encode-koi8-r-char): Removed.
* mule/cyril-util.el (cyrillic-encode-alternativnyj-char):
Removed. No-one uses these functions in google.com/codesearch,
GNU have a comment doubting their utility, and their
implementation is trivial.
* mule/cyril-util.el (cyrillic-language-alist):
Reformatted.
* mule/cyril-util.el (standard-display-table)): Removed. It wasn't
used anyway.
* mule/cyril-util.el (standard-display-cyrillic-translit):
Rewrite it to work with character tables as display tables, and
not to abort with an error.
2007-07-21 Aidan Kehoe <kehoea(a)parhasard.net>
* disp-table.el:
* disp-table.el (make-display-table): Moved earlier in the file in
a weak attempt at making syncing with GNU easier.
* disp-table.el (frob-display-table):
Autoload it, accept TAG-SET, for editing specifiers.
* disp-table.el (describe-display-table):
Have it handle character sets.
* disp-table.el (standard-display-8bit-1):
* disp-table.el (standard-display-8bit):
* disp-table.el (standard-display-default-1):
* disp-table.el (standard-display-ascii):
* disp-table.el (standard-display-g1):
* disp-table.el (standard-display-graphic):
* disp-table.el (standard-display-underline):
* disp-table.el (standard-display-european):
Rework them all to use put-char-table, remove-char-table instead
of aset. Limit standard-display-g1, standard-display-graphic to
TTYs; have standard-display-underline work on X11 too.
* font.el (font-caps-display-table):
Use put-char-table instead of aset when editing a display table.
* x-init.el:
* x-init.el (tab):
Create the initial display table as a char-table, not a vector.
diff -r cc293ef846d240af187a523bb32eb5e26a083531 -r e214ff9f9507794f61ad09d81e5f9272447c87d2 lisp/ChangeLog
--- a/lisp/ChangeLog Mon Dec 24 14:00:51 2007 +0100
+++ b/lisp/ChangeLog Mon Dec 24 20:22:08 2007 +0100
@@ -1,3 +1,46 @@ 2007-12-22 Stephen J. Turnbull <stephe
+2007-07-21 Aidan Kehoe <kehoea(a)parhasard.net>
+
+ * mule/cyril-util.el:
+ * mule/cyril-util.el (cyrillic-encode-koi8-r-char): Removed.
+ * mule/cyril-util.el (cyrillic-encode-alternativnyj-char):
+ Removed. No-one uses these functions in google.com/codesearch,
+ GNU have a comment doubting their utility, and their
+ implementation is trivial.
+ * mule/cyril-util.el (cyrillic-language-alist):
+ Reformatted.
+ * mule/cyril-util.el (standard-display-table)): Removed. It wasn't
+ used anyway.
+ * mule/cyril-util.el (standard-display-cyrillic-translit):
+ Rewrite it to work with character tables as display tables, and
+ not to abort with an error.
+
+2007-07-21 Aidan Kehoe <kehoea(a)parhasard.net>
+
+ * disp-table.el:
+ * disp-table.el (make-display-table): Moved earlier in the file in
+ a weak attempt at making syncing with GNU easier.
+ * disp-table.el (frob-display-table):
+ Autoload it, accept TAG-SET, for editing specifiers.
+ * disp-table.el (describe-display-table):
+ Have it handle character sets.
+ * disp-table.el (standard-display-8bit-1):
+ * disp-table.el (standard-display-8bit):
+ * disp-table.el (standard-display-default-1):
+ * disp-table.el (standard-display-ascii):
+ * disp-table.el (standard-display-g1):
+ * disp-table.el (standard-display-graphic):
+ * disp-table.el (standard-display-underline):
+ * disp-table.el (standard-display-european):
+ Rework them all to use put-char-table, remove-char-table instead
+ of aset. Limit standard-display-g1, standard-display-graphic to
+ TTYs; have standard-display-underline work on X11 too.
+
+ * font.el (font-caps-display-table):
+ Use put-char-table instead of aset when editing a display table.
+ * x-init.el:
+ * x-init.el (tab):
+ Create the initial display table as a char-table, not a vector.
+
2007-12-22 Stephen J. Turnbull <stephen(a)xemacs.org>
Factor out lists of operators specially treated by `make-autoload'.
diff -r cc293ef846d240af187a523bb32eb5e26a083531 -r e214ff9f9507794f61ad09d81e5f9272447c87d2 lisp/disp-table.el
--- a/lisp/disp-table.el Mon Dec 24 14:00:51 2007 +0100
+++ b/lisp/disp-table.el Mon Dec 24 20:22:08 2007 +0100
@@ -1,6 +1,6 @@
;;; disp-table.el --- functions for dealing with char tables.
-;; Copyright (C) 1987, 1994, 1997 Free Software Foundation, Inc.
+;; Copyright (C) 1987, 1994, 1997, 2007 Free Software Foundation, Inc.
;; Copyright (C) 1995 Sun Microsystems.
;; Author: Howard Gayle
@@ -28,56 +28,82 @@
;;; Commentary:
-;; #### Need lots of work. make-display-table depends on a value
-;; that is a define in the C code. Maybe we should just move the
-;; function into C.
-
-;; #### display-tables-as-vectors is really evil and a big pain in
-;; the ass.
-
;; Rewritten for XEmacs July 1995, Ben Wing.
;;; Code:
+
+;;;###autoload
+(defun make-display-table ()
+ "Return a new, empty display table.
+
+This returns a generic character table; previously it returned a vector, but
+that was not helpful when dealing with internationalized characters above
+#xFF. See `make-char-table' for details of character tables in general. To
+write code that works with both vectors and character tables, add something
+like the following to the beginning of your file, and use
+`put-display-table' to set what a given character is displayed as, and
+`get-display-table' to examine what that character is currently displayed
+as:
+
+\(defun-when-void put-display-table (range value display-table)
+ \"Set the value for char RANGE to VALUE in DISPLAY-TABLE. \"
+ (ecase (type-of display-table)
+ (vector
+ (aset display-table range value))
+ (char-table
+ (put-char-table range value display-table))))
+
+\(defun-when-void get-display-table (character display-table)
+ \"Find value for CHARACTER in DISPLAY-TABLE. \"
+ (ecase (type-of display-table)
+ (vector
+ (aref display-table character))
+ (char-table
+ (get-char-table character display-table))))
+
+In this implementation, `put-display-table' and `get-display-table' are
+aliases of `put-char-table' and `get-char-table' respectively, and are
+always available. "
+ (make-char-table 'generic))
+
+;;;###autoload
+(defalias 'put-display-table #'put-char-table)
+
+;;;###autoload
+(defalias 'get-display-table #'get-char-table)
(defun describe-display-table (dt)
"Describe the display table DT in a help buffer."
(with-displaying-help-buffer
(lambda ()
- (princ "\nCharacter display glyph sequences:\n")
- (save-excursion
- (let ((vector (make-vector 256 nil))
- (i 0))
- (while (< i 256)
- (aset vector i (aref dt i))
- (incf i))
- ;; FSF calls `describe-vector' here, but it is so incredibly
- ;; lame a function for that name that I cannot bring myself
- ;; to porting it. Here is what `describe-vector' does:
- (terpri)
- (let ((old (aref vector 0))
- (oldpos 0)
- (i 1)
- str)
- (while (<= i 256)
- (when (or (= i 256)
- (not (equal old (aref vector i))))
- (if (eq oldpos (1- i))
- (princ (format "%s\t\t%s\n"
- (single-key-description (int-char oldpos))
- old))
- (setq str (format "%s - %s"
- (single-key-description (int-char oldpos))
- (single-key-description (int-char (1- i)))))
- (princ str)
- (princ (make-string (max (- 2 (/ (length str)
- tab-width)) 1) ?\t))
- (princ old)
- (terpri))
- (or (= i 256)
- (setq old (aref vector i)
- oldpos i)))
- (incf i))))))))
+ (map-char-table
+ (lambda (range value)
+ (cond
+ ((eq range t)
+ (princ "\nAll characters: \n")
+ (princ (format " %S" value)))
+ ((eq 'charset (and (symbolp range) (type-of (find-charset range))))
+ (princ (format "\n\nCharset %S: \n" (charset-name range)))
+ (princ (format " %S" value)))
+ ((vectorp range)
+ (princ (format "\n\nCharset %S, row %d \n"
+ (charset-name (aref value 0))
+ (aref value 1)))
+ (princ (format " %S\n\n" value)))
+ ((characterp range)
+ (princ (format "\nCharacter U+%04X, %S: "
+ range (if (fboundp 'split-char)
+ (split-char range)
+ (list 'ascii (char-to-int range)))))
+ (princ (format " %S" value))))
+ nil) dt)
+ (princ
+ "\n\nFor some of the various other glyphs that GNU Emacs uses the display
+table for, see the XEmacs specifiers `truncation-glyph' ,
+`continuation-glyph', `control-arrow-glyph', `octal-escape-glyph' and the
+others described in the docstring of `make-glyph'. \n\n"))))
+
;;;###autoload
(defun describe-current-display-table (&optional domain)
@@ -89,21 +115,17 @@
(describe-display-table disptab)
(message "No display table"))))
-;;;###autoload
-(defun make-display-table ()
- "Return a new, empty display table."
- (make-vector 256 nil))
-
;; #### we need a generic frob-specifier function.
;; #### this also needs to be redone like frob-face-property.
;; Let me say one more time how much dynamic scoping sucks.
-(defun frob-display-table (fdt-function fdt-locale)
+;;;###autoload
+(defun frob-display-table (fdt-function fdt-locale &optional tag-set)
(or fdt-locale (setq fdt-locale 'global))
- (or (specifier-spec-list current-display-table fdt-locale)
+ (or (specifier-spec-list current-display-table fdt-locale tag-set)
(add-spec-to-specifier current-display-table (make-display-table)
- fdt-locale))
+ fdt-locale tag-set))
(add-spec-list-to-specifier
current-display-table
(list (cons fdt-locale
@@ -112,29 +134,44 @@
(funcall fdt-function (cdr fdt-x))
fdt-x)
(cdar (specifier-spec-list current-display-table
- fdt-locale)))))))
+ fdt-locale tag-set)))))))
(defun standard-display-8bit-1 (dt l h)
(while (<= l h)
- (aset dt l (char-to-string l))
+ (remove-char-table (int-to-char l) dt)
(setq l (1+ l))))
;;;###autoload
(defun standard-display-8bit (l h &optional locale)
- "Display characters in the range L to H literally."
+ "Display characters in the range L to H literally [sic].
+
+GNU Emacs includes this function. There, `literally' has no good meaning.
+Under XEmacs, this function makes characters with numeric values in the
+range L to H display as themselves; that is, as ASCII, latin-iso8859-1,
+latin-iso8859-2 or whatever. See `standard-display-default' for the inverse
+function. "
(frob-display-table
(lambda (x)
(standard-display-8bit-1 x l h))
locale))
(defun standard-display-default-1 (dt l h)
+ "Misnamed function under XEmacs. See `standard-display-default'."
(while (<= l h)
- (aset dt l nil)
+ (put-char-table (int-to-char l) (format "\\%o" l) dt)
(setq l (1+ l))))
;;;###autoload
(defun standard-display-default (l h &optional locale)
- "Display characters in the range L to H using the default notation."
+ "Display characters in the range L to H using octal escape notation.
+
+In the XEmacs context this function is misnamed. Under GNU Emacs,
+characters in the range #xA0 to #xFF display as octal escapes unless
+`standard-display-european' has been called; this function neutralizes the
+effects of `standard-display-european'. Under XEmacs, those characters
+normally do not display as octal escapes (this ignores hackery like
+specifying the X11 font character set on non-Mule builds) and this function
+sets them to display as octal escapes. "
(frob-display-table
(lambda (x)
(standard-display-default-1 x l h))
@@ -145,11 +182,8 @@
"Display character C using printable string S."
(frob-display-table
(lambda (x)
- (aset x c s))
- locale))
-
-
-;;; #### should frob in a 'tty locale.
+ (put-char-table c s x))
+ locale))
;;;###autoload
(defun standard-display-g1 (c sc &optional locale)
@@ -158,11 +192,8 @@ it is meaningless for an X frame."
it is meaningless for an X frame."
(frob-display-table
(lambda (x)
- (aset x c (concat "\016" (char-to-string sc) "\017")))
- locale))
-
-
-;;; #### should frob in a 'tty locale.
+ (put-char-table c (concat "\016" (char-to-string sc) "\017") x))
+ locale '(tty)))
;;;###autoload
(defun standard-display-graphic (c gc &optional locale)
@@ -171,37 +202,41 @@ X frame."
X frame."
(frob-display-table
(lambda (x)
- (aset x c (concat "\e(0" (char-to-string gc) "\e(B")))
- locale))
-
-;;; #### should frob in a 'tty locale.
-;;; #### the FSF equivalent of this makes this character be displayed
-;;; in the 'underline face. There's no current way to do this with
-;;; XEmacs display tables.
+ (put-char-table c (concat "\e(0" (char-to-string gc) "\e(B") x))
+ locale '(tty)))
;;;###autoload
(defun standard-display-underline (c uc &optional locale)
"Display character C as character UC plus underlining."
(frob-display-table
(lambda (x)
- (aset x c (concat "\e[4m" (char-to-string uc) "\e[m")))
+ (let (glyph)
+ (setq glyph (make-glyph (vector 'string :data (char-to-string uc))))
+ (set-glyph-face glyph 'underline)
+ (put-char-table c glyph x)))
locale))
;;;###autoload
(defun standard-display-european (arg &optional locale)
- "Toggle display of European characters encoded with ISO 8859.
-When enabled, characters in the range of 160 to 255 display not
-as octal escapes, but as accented characters.
-With prefix argument, enable European character display iff arg is positive."
+ "Toggle display of European characters encoded with ISO 8859-1.
+When enabled (the default), characters in the range of 160 to 255 display
+as accented characters. With negative prefix argument, display characters in
+that range as octal escapes.
+
+If you want to work in a Western European language under XEmacs, it
+shouldn't be necessary to call this function--things should just work. But
+it's in a sufficient number of init files that we're not in a hurry to
+remove it. "
(interactive "P")
- (frob-display-table
- (lambda (x)
- (if (or (<= (prefix-numeric-value arg) 0)
- (and (null arg)
- (equal (aref x 160) (char-to-string 160))))
- (standard-display-default-1 x 160 255)
- (standard-display-8bit-1 x 160 255)))
- locale))
+ (if (<= (prefix-numeric-value arg) 0)
+ (frob-display-table
+ (lambda (x)
+ (standard-display-default-1 x 160 255))
+ locale)
+ (frob-display-table
+ (lambda (x)
+ (standard-display-8bit-1 x 160 255))
+ locale)))
(provide 'disp-table)
diff -r cc293ef846d240af187a523bb32eb5e26a083531 -r e214ff9f9507794f61ad09d81e5f9272447c87d2 lisp/font.el
--- a/lisp/font.el Mon Dec 24 14:00:51 2007 +0100
+++ b/lisp/font.el Mon Dec 24 20:22:08 2007 +0100
@@ -254,17 +254,17 @@ for use in the 'weight' field of an X fo
(i 0))
;; Standard ASCII characters
(while (< i 26)
- (aset table (+ i ?a) (+ i ?A))
+ (put-display-table (+ i ?a) (+ i ?A) table)
(setq i (1+ i)))
;; Now ISO translations
;; #### FIXME what's this for??
(setq i 224)
(while (< i 247) ;; Agrave - Ouml
- (aset table i (- i 32))
+ (put-display-table i (- i 32) table)
(setq i (1+ i)))
(setq i 248)
(while (< i 255) ;; Oslash - Thorn
- (aset table i (- i 32))
+ (put-display-table i (- i 32) table)
(setq i (1+ i)))
table))
diff -r cc293ef846d240af187a523bb32eb5e26a083531 -r e214ff9f9507794f61ad09d81e5f9272447c87d2 lisp/mule/cyril-util.el
--- a/lisp/mule/cyril-util.el Mon Dec 24 14:00:51 2007 +0100
+++ b/lisp/mule/cyril-util.el Mon Dec 24 20:22:08 2007 +0100
@@ -26,17 +26,11 @@
;;; Commentary:
+;;; #### Remove this, use the one in packages instead, but with the below
+;;; standard-display-cyrillic-translit. This file is unfortunately shadowed
+;;; if you have the Mule packages installed!
+
;;; Code:
-
-;;;###autoload
-(defun cyrillic-encode-koi8-r-char (char)
- "Return KOI8-R external character code of CHAR if appropriate."
- (get-char-table char cyrillic-koi8-r-to-external-code-table))
-
-;;;###autoload
-(defun cyrillic-encode-alternativnyj-char (char)
- "Return ALTERNATIVNYJ external character code of CHAR if appropriate."
- (get-char-table char cyrillic-alternativnyj-to-external-code-table))
;; Display
@@ -44,11 +38,9 @@
;; Written by Valery Alexeev <valery(a)math.uga.edu>.
(defvar cyrillic-language-alist
- (list '("Belorussian") '("Bulgarian") '("Macedonian")
- '("Russian") '("Serbian") '("Ukrainian"))
- "*List of known cyrillic languages")
-
-(defvar standard-display-table)
+ '(("Belorussian") ("Bulgarian") ("Macedonian") ("Russian") ("Serbian")
+ ("Ukrainian"))
+ "*List of known Cyrillic languages")
;;;###autoload
(defun standard-display-cyrillic-translit (&optional cyrillic-language)
@@ -67,129 +59,122 @@ If the argument is nil, we return the di
(completing-read
"Cyrillic language (default nil): "
cyrillic-language-alist nil t nil nil nil))))
+ (when (equal cyrillic-language "")
+ (setq cyrillic-language nil))
+ (frob-display-table
+ (lambda (display-table)
+ (if (null cyrillic-language)
+ (if (char-table-p display-table)
+ (remove-char-table 'cyrillic-iso8859-5 display-table))
+ (put-display-table ?,LP(B "a" display-table)
+ (put-display-table ?,LQ(B "b" display-table)
+ (put-display-table ?,LR(B "v" display-table)
+ (put-display-table ?,LS(B "g" display-table)
+ (put-display-table ?,LT(B "d" display-table)
+ (put-display-table ?,LU(B "e" display-table)
+ (put-display-table ?,Lq(B "yo" display-table)
+ (put-display-table ?,LV(B "zh" display-table)
+ (put-display-table ?,LW(B "z" display-table)
+ (put-display-table ?,LX(B "i" display-table)
+ (put-display-table ?,LY(B "j" display-table)
+ (put-display-table ?,LZ(B "k" display-table)
+ (put-display-table ?,L[(B "l" display-table)
+ (put-display-table ?,L\(B "m" display-table)
+ (put-display-table ?,L](B "n" display-table)
+ (put-display-table ?,L^(B "o" display-table)
+ (put-display-table ?,L_(B "p" display-table)
+ (put-display-table ?,L`(B "r" display-table)
+ (put-display-table ?,La(B "s" display-table)
+ (put-display-table ?,Lb(B "t" display-table)
+ (put-display-table ?,Lc(B "u" display-table)
+ (put-display-table ?,Ld(B "f" display-table)
+ (put-display-table ?,Le(B "kh" display-table)
+ (put-display-table ?,Lf(B "ts" display-table)
+ (put-display-table ?,Lg(B "ch" display-table)
+ (put-display-table ?,Lh(B "sh" display-table)
+ (put-display-table ?,Li(B "sch" display-table)
+ (put-display-table ?,Lj(B "~" display-table)
+ (put-display-table ?,Lk(B "y" display-table)
+ (put-display-table ?,Ll(B "'" display-table)
+ (put-display-table ?,Lm(B "e'" display-table)
+ (put-display-table ?,Ln(B "yu" display-table)
+ (put-display-table ?,Lo(B "ya" display-table)
+ (put-display-table ?,L0(B "A" display-table)
+ (put-display-table ?,L1(B "B" display-table)
+ (put-display-table ?,L2(B "V" display-table)
+ (put-display-table ?,L3(B "G" display-table)
+ (put-display-table ?,L4(B "D" display-table)
+ (put-display-table ?,L5(B "E" display-table)
+ (put-display-table ?,L!(B "Yo" display-table)
+ (put-display-table ?,L6(B "Zh" display-table)
+ (put-display-table ?,L7(B "Z" display-table)
+ (put-display-table ?,L8(B "I" display-table)
+ (put-display-table ?,L9(B "J" display-table)
+ (put-display-table ?,L:(B "K" display-table)
+ (put-display-table ?,L;(B "L" display-table)
+ (put-display-table ?,L<(B "M" display-table)
+ (put-display-table ?,L=(B "N" display-table)
+ (put-display-table ?,L>(B "O" display-table)
+ (put-display-table ?,L?(B "P" display-table)
+ (put-display-table ?,L@(B "R" display-table)
+ (put-display-table ?,LA(B "S" display-table)
+ (put-display-table ?,LB(B "T" display-table)
+ (put-display-table ?,LC(B "U" display-table)
+ (put-display-table ?,LD(B "F" display-table)
+ (put-display-table ?,LE(B "Kh" display-table)
+ (put-display-table ?,LF(B "Ts" display-table)
+ (put-display-table ?,LG(B "Ch" display-table)
+ (put-display-table ?,LH(B "Sh" display-table)
+ (put-display-table ?,LI(B "Sch" display-table)
+ (put-display-table ?,LJ(B "~" display-table)
+ (put-display-table ?,LK(B "Y" display-table)
+ (put-display-table ?,LL(B "'" display-table)
+ (put-display-table ?,LM(B "E'" display-table)
+ (put-display-table ?,LN(B "Yu" display-table)
+ (put-display-table ?,LO(B "Ya" display-table)
+ (put-display-table ?,Lt(B "ie" display-table)
+ (put-display-table ?,Lw(B "i" display-table)
+ (put-display-table ?,L~(B "u" display-table)
+ (put-display-table ?,Lr(B "dj" display-table)
+ (put-display-table ?,L{(B "chj" display-table)
+ (put-display-table ?,Ls(B "gj" display-table)
+ (put-display-table ?,Lu(B "s" display-table)
+ (put-display-table ?,L|(B "k" display-table)
+ (put-display-table ?,Lv(B "i" display-table)
+ (put-display-table ?,Lx(B "j" display-table)
+ (put-display-table ?,Ly(B "lj" display-table)
+ (put-display-table ?,Lz(B "nj" display-table)
+ (put-display-table ?,L(B "dz" display-table)
+ (put-display-table ?,L$(B "Ye" display-table)
+ (put-display-table ?,L'(B "Yi" display-table)
+ (put-display-table ?,L.(B "U" display-table)
+ (put-display-table ?,L"(B "Dj" display-table)
+ (put-display-table ?,L+(B "Chj" display-table)
+ (put-display-table ?,L#(B "Gj" display-table)
+ (put-display-table ?,L%(B "S" display-table)
+ (put-display-table ?,L,(B "K" display-table)
+ (put-display-table ?,L&(B "I" display-table)
+ (put-display-table ?,L((B "J" display-table)
+ (put-display-table ?,L)(B "Lj" display-table)
+ (put-display-table ?,L*(B "Nj" display-table)
+ (put-display-table ?,L/(B "Dj" display-table)
+
+ (when (equal cyrillic-language "Bulgarian")
+ (put-display-table ?,Li(B "sht" display-table)
+ (put-display-table ?,LI(B "Sht" display-table)
+ (put-display-table ?,Ln(B "iu" display-table)
+ (put-display-table ?,LN(B "Iu" display-table)
+ (put-display-table ?,Lo(B "ia" display-table)
+ (put-display-table ?,LO(B "Ia" display-table))
- (or standard-display-table
- (setq standard-display-table (make-display-table)))
-
- (if (equal cyrillic-language "")
- (setq cyrillic-language nil))
-
- (if (null cyrillic-language)
- (setq standard-display-table (make-display-table))
- (aset standard-display-table ?,LP(B [?a])
- (aset standard-display-table ?,LQ(B [?b])
- (aset standard-display-table ?,LR(B [?v])
- (aset standard-display-table ?,LS(B [?g])
- (aset standard-display-table ?,LT(B [?d])
- (aset standard-display-table ?,LU(B [?e])
- (aset standard-display-table ?,Lq(B [?y?o])
- (aset standard-display-table ?,LV(B [?z?h])
- (aset standard-display-table ?,LW(B [?z])
- (aset standard-display-table ?,LX(B [?i])
- (aset standard-display-table ?,LY(B [?j])
- (aset standard-display-table ?,LZ(B [?k])
- (aset standard-display-table ?,L[(B [?l])
- (aset standard-display-table ?,L\(B [?m])
- (aset standard-display-table ?,L](B [?n])
- (aset standard-display-table ?,L^(B [?o])
- (aset standard-display-table ?,L_(B [?p])
- (aset standard-display-table ?,L`(B [?r])
- (aset standard-display-table ?,La(B [?s])
- (aset standard-display-table ?,Lb(B [?t])
- (aset standard-display-table ?,Lc(B [?u])
- (aset standard-display-table ?,Ld(B [?f])
- (aset standard-display-table ?,Le(B [?k?h])
- (aset standard-display-table ?,Lf(B [?t?s])
- (aset standard-display-table ?,Lg(B [?c?h])
- (aset standard-display-table ?,Lh(B [?s?h])
- (aset standard-display-table ?,Li(B [?s?c?h])
- (aset standard-display-table ?,Lj(B [?~])
- (aset standard-display-table ?,Lk(B [?y])
- (aset standard-display-table ?,Ll(B [?'])
- (aset standard-display-table ?,Lm(B [?e?'])
- (aset standard-display-table ?,Ln(B [?y?u])
- (aset standard-display-table ?,Lo(B [?y?a])
-
- (aset standard-display-table ?,L0(B [?A])
- (aset standard-display-table ?,L1(B [?B])
- (aset standard-display-table ?,L2(B [?V])
- (aset standard-display-table ?,L3(B [?G])
- (aset standard-display-table ?,L4(B [?D])
- (aset standard-display-table ?,L5(B [?E])
- (aset standard-display-table ?,L!(B [?Y?o])
- (aset standard-display-table ?,L6(B [?Z?h])
- (aset standard-display-table ?,L7(B [?Z])
- (aset standard-display-table ?,L8(B [?I])
- (aset standard-display-table ?,L9(B [?J])
- (aset standard-display-table ?,L:(B [?K])
- (aset standard-display-table ?,L;(B [?L])
- (aset standard-display-table ?,L<(B [?M])
- (aset standard-display-table ?,L=(B [?N])
- (aset standard-display-table ?,L>(B [?O])
- (aset standard-display-table ?,L?(B [?P])
- (aset standard-display-table ?,L@(B [?R])
- (aset standard-display-table ?,LA(B [?S])
- (aset standard-display-table ?,LB(B [?T])
- (aset standard-display-table ?,LC(B [?U])
- (aset standard-display-table ?,LD(B [?F])
- (aset standard-display-table ?,LE(B [?K?h])
- (aset standard-display-table ?,LF(B [?T?s])
- (aset standard-display-table ?,LG(B [?C?h])
- (aset standard-display-table ?,LH(B [?S?h])
- (aset standard-display-table ?,LI(B [?S?c?h])
- (aset standard-display-table ?,LJ(B [?~])
- (aset standard-display-table ?,LK(B [?Y])
- (aset standard-display-table ?,LL(B [?'])
- (aset standard-display-table ?,LM(B [?E?'])
- (aset standard-display-table ?,LN(B [?Y?u])
- (aset standard-display-table ?,LO(B [?Y?a])
-
- (aset standard-display-table ?,Lt(B [?i?e])
- (aset standard-display-table ?,Lw(B [?i])
- (aset standard-display-table ?,L~(B [?u])
- (aset standard-display-table ?,Lr(B [?d?j])
- (aset standard-display-table ?,L{(B [?c?h?j])
- (aset standard-display-table ?,Ls(B [?g?j])
- (aset standard-display-table ?,Lu(B [?s])
- (aset standard-display-table ?,L|(B [?k])
- (aset standard-display-table ?,Lv(B [?i])
- (aset standard-display-table ?,Lx(B [?j])
- (aset standard-display-table ?,Ly(B [?l?j])
- (aset standard-display-table ?,Lz(B [?n?j])
- (aset standard-display-table ?,L(B [?d?z])
-
- (aset standard-display-table ?,L$(B [?Y?e])
- (aset standard-display-table ?,L'(B [?Y?i])
- (aset standard-display-table ?,L.(B [?U])
- (aset standard-display-table ?,L"(B [?D?j])
- (aset standard-display-table ?,L+(B [?C?h?j])
- (aset standard-display-table ?,L#(B [?G?j])
- (aset standard-display-table ?,L%(B [?S])
- (aset standard-display-table ?,L,(B [?K])
- (aset standard-display-table ?,L&(B [?I])
- (aset standard-display-table ?,L((B [?J])
- (aset standard-display-table ?,L)(B [?L?j])
- (aset standard-display-table ?,L*(B [?N?j])
- (aset standard-display-table ?,L/(B [?D?j])
-
- (when (equal cyrillic-language "Bulgarian")
- (aset standard-display-table ?,Li(B [?s?h?t])
- (aset standard-display-table ?,LI(B [?S?h?t])
- (aset standard-display-table ?,Ln(B [?i?u])
- (aset standard-display-table ?,LN(B [?I?u])
- (aset standard-display-table ?,Lo(B [?i?a])
- (aset standard-display-table ?,LO(B [?I?a]))
-
- (when (equal cyrillic-language "Ukrainian") ; based on the official
- ; transliteration table
- (aset standard-display-table ?,LX(B [?y])
- (aset standard-display-table ?,L8(B [?Y])
- (aset standard-display-table ?,LY(B [?i])
- (aset standard-display-table ?,L9(B [?Y])
- (aset standard-display-table ?,Ln(B [?i?u])
- (aset standard-display-table ?,Lo(B [?i?a]))))
-
-
+ (when (equal cyrillic-language "Ukrainian") ; based on the official
+ ; transliteration table
+ (put-display-table ?,LX(B "y" display-table)
+ (put-display-table ?,L8(B "Y" display-table)
+ (put-display-table ?,LY(B "i" display-table)
+ (put-display-table ?,L9(B "Y" display-table)
+ (put-display-table ?,Ln(B "iu" display-table)
+ (put-display-table ?,Lo(B "ia" display-table)))) nil))
;;
(provide 'cyril-util)
diff -r c32b3d10c56b nt/xemacs.mak
--- a/nt/xemacs.mak Sat Apr 26 16:28:44 2008 +0200
+++ b/nt/xemacs.mak Wed May 14 10:02:09 2008 +0200
@@ -794,7 +794,7 @@ INCLUDES=-I$(NT)\inc -I$(SRC) $(OPT_INCL
INCLUDES=-I$(NT)\inc -I$(SRC) $(OPT_INCLUDES)
DEFINES=$(OPT_DEFINES) \
- -DWIN32_LEAN_AND_MEAN -DWIN32_NATIVE -Demacs \
+ -DWIN32_LEAN_AND_MEAN -DWIN32_NATIVE -Demacs -DNTDDI_VERSION=NTDDI_WIN2K -D_WIN32_WINNT=_WIN32_WINNT_WIN2K \
-DHAVE_CONFIG_H $(PROGRAM_DEFINES) $(PATH_DEFINES)
CFLAGS_NO_OPT=-nologo -W3 -DSTRICT $(DEBUG_FLAGS_COMPILE)
Bye,
Aidan
Ar an ceathrú lá déag de mí Bealtaine, scríobh Robert Pluim:
> On Sat, May 10, 2008 at 8:36 AM, Stephen J. Turnbull <stephen(a)xemacs.org>
> wrote:
>
> > Matthew Persico writes:
> >
> > > Now I am left with this:
> > >
> > > c:\opt\xemacs\src\xemacs-21.5.28\src\intl-auto-encap-win32.h(80) :
> > > error C2061: syntax error : identifier 'LPSHQUERYRBINFO'
> > >
> > > The code in question is this:
> > >
> > > HRESULT qxeSHQueryRecycleBin (const Extbyte * pszRootPath,
> > > LPSHQUERYRBINFO pSHQueryRBInfo);
> >
> > > Twenty lines later we have these two lines, which seem to be happy:
> >
> > How do you know they're happy? Many compilers will crap out on the
> > first error and stop there.
> >
> > To test that you could just comment out line 80.
> >
> > Are you sure that the relevant part of ShellAPI.h is being included?
> > Maybe there's a conditional. Or maybe somehow ShellAPI.h itself is
> > not getting included.
> >
> > I don't know how to check those on Windows, though.
> >
>
> I've attached a diff of what I did to get this to work a while back.
> Basically it looks like the defines needed by the windows header files have
> changed.
>
> Let's hope gmail doesn't mangle the attachment.
>
> Robert
diff -r cc293ef846d240af187a523bb32eb5e26a083531 -r e214ff9f9507794f61ad09d81e5f9272447c87d2 lisp/x-init.el
--- a/lisp/x-init.el Mon Dec 24 14:00:51 2007 +0100
+++ b/lisp/x-init.el Mon Dec 24 20:22:08 2007 +0100
@@ -336,11 +336,11 @@ This function is a trivial wrapper aroun
;; due to a universally crocked font width specification. Display it
;; as a space since that's what seems to be expected.
;;
-;; (make-vector 256 nil) instead of (make-display-table) because
-;; make-display-table doesn't exist when this file is loaded.
-
-(let ((tab (make-vector 256 nil)))
- (aset tab 160 " ")
+;; (make-char-table 'generic) instead of (make-display-table) because
+;; make-display-table isn't dumped, and this file is.
+
+(let ((tab (make-char-table 'generic)))
+ (put-char-table 160 " " tab)
(set-specifier current-display-table tab 'global 'x))
;;; x-init.el ends here
_______________________________________________
XEmacs-Patches mailing list
XEmacs-Patches(a)xemacs.org
http://calypso.tux.org/cgi-bin/mailman/listinfo/xemacs-patches
Re: FAILED: 21.5.26 build with MSVC++ 2008 Starter edition
16 years, 7 months
Aidan Kehoe
Hi Robert --
I’ve committed part of your patch, modified slightly to reflect the
environment variables available to me:
http://mid.gmane.org/E1Jytgc-0002zM-6b@alioth.debian.org
The auto-generated Win32 intl code is incomplete for me, even with that
change, so I didn’t commit it--looks like we need to work out accurate
minimum specifications for the Windows compiler.
A question; what did this part of your patch do exactly?
--
¿Dónde estará ahora mi sobrino Yoghurtu Nghé, que tuvo que huir
precipitadamente de la aldea por culpa de la escasez de rinocerontes?
_______________________________________________
XEmacs-Patches mailing list
XEmacs-Patches(a)xemacs.org
http://calypso.tux.org/cgi-bin/mailman/listinfo/xemacs-patches